@@ -7,6 +7,9 @@ dataset_group = Dict[str, DataFrame]
 
 
 class EtlBase:
+    def __init__(self):
+        super().__init__()
+
     @abstractmethod
     def etl(self, inputs: dataset_group) -> dataset_group:
         raise NotImplementedError()
