@@ -2,11 +2,13 @@
 A collection of useful pyspark snippets.
 """
 
-from atc.spark import Spark
+import uuid as _uuid
+
 from pyspark.sql.functions import udf
 from pyspark.sql.types import StringType
-import uuid as _uuid
+
 from atc.atc_exceptions import NoTableException
+from atc.spark import Spark
 
 # Pyspark uuid function implemented as recommended here
 # https://stackoverflow.com/questions/49785108/spark-streaming-with-python-how-to-add-a-uuid-column/50095755
@@ -27,9 +29,10 @@ def init_dbutils():
 
 def drop_table_cascade(DBDotTableName: str) -> None:
     """
-    drop_table_cascade drops a databricks database table and remove the files permanently
+    drop_table_cascade drops a databricks database table
+    and remove the files permanently
 
-    :param p1: db.tablename
+    :param DBDotTableName: db.tablename
 
     return None
 
@@ -47,10 +50,16 @@ def drop_table_cascade(DBDotTableName: str) -> None:
     )
 
     if table_path is None:
-        raise NoTableException(f"Table path is NONE.")
+        raise NoTableException("Table path is NONE.")
 
     # Remove files associated with table
     init_dbutils().fs.rm(table_path, recurse=True)
 
     # Remove table
     Spark.get().sql(f"DROP TABLE IF EXISTS {DBDotTableName}")
+
+
+def get_unique_tempview_name() -> str:
+    unique_id = _uuid.uuid4().hex
+    temp_view_name = f"source_{unique_id}"
+    return temp_view_name
